Skip to contents

A wrapper for purrr::map2. It takes two ggdiagram objects with multiple elements, applies a function to each element within the objects, and returns a ggdiagram object

Usage

map2_ob(.x, .y, .f, ..., .progress = FALSE)

Arguments

.x

a ggdiagram object

.y

a ggdiagram object

.f

a function that returns a ggdiagram object

...

<dynamic-dots> arguments passed to .f

.progress

display progress if TRUE

Value

a ggdiagram object