Finds the "previous" (lag) or "next" (lead) values in a vector or object with values at the end of the vector recycled to the beginning.
Source:R/a_early.R
lead_cycle.RdFinds the "previous" (lag) or "next" (lead) values in a vector or object with values at the end of the vector recycled to the beginning.