ob_circle class
Arguments
- center
Point at center of the circle
- radius
Distance between center and edge circle
- label
A character, angle, or label object
- alpha
numeric value for alpha transparency
- color
character string for color
- fill
character string for fill color
- linewidth
Width of lines
- linetype
type of lines
- n
Number of points in circle (default = 360)
- style
An ob_style object
- x
x-coordinate of center point. If specified, overrides x-coordinate of
@center.- y
x-coordinate of center point. If specified, overrides y-coordinate of
@center.- id
character string to identify object
- ...
<
dynamic-dots> properties passed to style object
Additional properties
@aestheticsA list of information about the circle's aesthetic properties
@angle_atA function that finds the angle of the specified point in relation to the circle's center
@arcA function that creates an arc object with the same center as the circle object. Must specify the
startangle and theendangle. In addition, any of the parameters ofob_arccan be applied.@areaarea of the circle
@bounding_boxA rectangle that contains all the circles
@circumferenceCircumference of the circle
@diameterThe diameter of the circle
@geomA function that converts the object to a geom. Any additional parameters are passed to
ggforce::geom_circle.@lengthThe number of circles in the circle object
@normal_atA function that finds a point that is perpendicular from the circle and at a specified distance
@point_atA function that finds a point on the circle at the specified angle
@polar_line_atA function that creates an
ob_linethat passes through the circle's center and the point specified inx@polygonA tibble containing information to create all the polygon points in a circle
@tangent_atA function that finds the tangent line at the specified angle
@tibbleGets a tibble (data.frame) containing parameters and styles used by
ggforce::geom_circle@eastob_pointat rightmost point of circle@northob_pointat highest point of circle@westob_pointat leftmost point of circle@southob_pointat lowest point of circle@northeastob_pointat top-right point of circle@northwestob_pointat top-left point of circle@southwestob_pointat bottom-left point of circle@southeastob_pointat bottom-right point of circle
Examples
# specify center point and radius
ob_circle(center = ob_point(0,0), radius = 6)
#>
#> ── <ob_circle>
#> # A tibble: 1 × 3
#> x y r
#> <dbl> <dbl> <dbl>
#> 1 0 0 6